pub struct AutoIndexSelector;Expand description
Auto-index selector
Implementations
Sourceimpl AutoIndexSelector
impl AutoIndexSelector
Sourcepub fn select(
data: &DataCharacteristics,
requirements: &IndexRequirements,
) -> IndexRecommendation
pub fn select( data: &DataCharacteristics, requirements: &IndexRequirements, ) -> IndexRecommendation
Select the optimal index based on data characteristics and requirements
Sourcepub fn quick_select(num_vectors: usize, dimensions: usize) -> RecommendedIndex
pub fn quick_select(num_vectors: usize, dimensions: usize) -> RecommendedIndex
Quick recommendation based on just vector count and dimensions