pub struct AnimationRef { /* private fields */ }Implementations
Sourceimpl AnimationRef
impl AnimationRef
Sourcepub fn on_start<F: Into<AnimationCallback>>(
&self,
handler: F,
once: bool,
) -> &Self
pub fn on_start<F: Into<AnimationCallback>>( &self, handler: F, once: bool, ) -> &Self
Add a callback that is triggered when the animation is started.
Sourcepub fn on_update<F: Into<AnimationCallback>>(
&self,
handler: F,
once: bool,
) -> &Self
pub fn on_update<F: Into<AnimationCallback>>( &self, handler: F, once: bool, ) -> &Self
Add a callback that is triggered when the animation is updated.
Sourcepub fn on_finish<F: Into<AnimationCallback>>(
&self,
handler: F,
once: bool,
) -> &Self
pub fn on_finish<F: Into<AnimationCallback>>( &self, handler: F, once: bool, ) -> &Self
Add a callback that is triggered when the animation is finished.